@@ -7,11 +7,11 @@ def run():
 	sys.path.append(os.path.abspath("."))
 
 	C = argparse.ArgumentParser()
-	C.add_argument("-p" , type = int , default = 8000)
+	C.add_argument("--port" , type = int , default = 8000)
 	C = C.parse_args()
 
 	if os.system("python manage.py migrate") > 0:
 		os.system("python3 manage.py migrate")
 
-	if os.system("python manage.py runserver 0.0.0.0:%d" % (C.p)) > 0:
-		os.system("python3 manage.py runserver")
\ No newline at end of file
+	if os.system("python manage.py runserver 0.0.0.0:%d" % (C.port)) > 0:
+		os.system("python3 manage.py runserver 0.0.0.0:%d" % (C.port))
\ No newline at end of file
